@@ -39,6 +39,10 @@ file.
 	
 	print "Title=$stationTitle\n";
 	
+	my $stationDescription = $station->getTitle('desc');
+	
+	print "Description=$stationDescription\n";
+	
 	my $stationID = $station->getID();
 
 	print "Station ID=$stationID\n";
@@ -134,21 +138,21 @@ Current options are:  I<-random> and I<-noplaylists>.  By default, the
 first ("best"?) stream is returned.  If I<-random> is specified, then 
 a random one is selected from the list of streams found.  
 If I<-noplaylists> is specified, and the stream to be returned is a 
-"playlist" (.pls extension), it is first fetched and the first entry 
+"playlist" (.pls or .m3u? extension), it is first fetched and the first entry 
 in the playlist is returned.  This is needed by Fauxdacious Mediaplayer.
 
 =item $station->B<count>()
 
 Returns the number of streams found for the station.
 
-=item $station->B<getID>([ 'iheart' | 'fccid' ])
+=item $station->B<getID>(['fccid'])
 
-Returns the station's FCC call-letters (default) or 
-station's IHeartRadio ID.
+Returns the station's IHeartRadio ID (default) or 
+station's FCC call-letters ("fccid").
 
-=item $station->B<getTitle>()
+=item $station->B<getTitle>(['desc'])
 
-Returns the station's title (description).  
+Returns the station's title, or (long description).  
 
 =item $station->B<getIconURL>()
 
@@ -218,7 +222,11 @@ iheartradio
 
 =head1 DEPENDENCIES
 
-LWP::UserAgent
+L<URI::Escape>, L<HTML::Entities>, L<LWP::UserAgent>
+
+=head1 RECCOMENDS
+
+wget
 
 =head1 BUGS
 
@@ -300,6 +308,8 @@ package StreamFinder::IHeartRadio;
 
 use strict;
 use warnings;
+use URI::Escape;
+use HTML::Entities ();
 use LWP::UserAgent ();
 use vars qw(@ISA @EXPORT);
 
@@ -379,8 +389,12 @@ sub new
 	print STDERR "-0(IHeartRadio): URL=$url= KEEP=(",join('|',@okStreams).") SKIP=(",join('|',@skipStreams).")\n"  if ($DEBUG);
 
 	(my $url2fetch = $url);
-	$url2fetch = 'https://www.iheart.com/live/' . $url . '/'  unless ($url =~ /^http/);
-	$self->{'id'} = $1  if ($url2fetch =~ m#\/([^\/]+)\/$#);
+	if ($url =~ /^https?\:/) {
+		$self->{'id'} = $1  if ($url2fetch =~ m#\/([^\/]+)\/?$#);
+	} else {
+		$self->{'id'} = $url;
+		$url2fetch = 'https://www.iheart.com/live/' . $url;
+	}
 	my $html = '';
 	print STDERR "-0(IHeartRadio): URL=$url2fetch=\n"  if ($DEBUG);
 	my $ua = LWP::UserAgent->new(@userAgentOps);		
@@ -411,10 +425,27 @@ sub new
 		$id = $1  if ($id =~ m#([^\/]+)$#);
 		$self->{'id'} = $id;
 		$self->{'title'} = ($html =~ s#\<title[^\>]+\>([^\<]+)\<\/title\>##s) ? $1 : '';
+		$self->{'description'} = ($html =~ m#\"podcastDescription\"\>(?:\<[^\>]+\>)?([^\<]+)#s) ? $1 : $self->{'title'};
+		$self->{'description'} = HTML::Entities::decode_entities($self->{'description'});
+		$self->{'description'} = uri_unescape($self->{'description'});
+		if ($html =~ m#\<span class\=\"css\-\w+ \w+\"\>\<span\>([^\<]+)\<\/span\>\<\/span\>\<\/a\>\</div\>\<span\>\<div class\=\"css\-\w+ \w+\"\>([^\<]+)\<\!\-\- \-\-\>#) {
+			$self->{'title'} = $1;
+			$self->{'created'} = $2;
+			$self->{'year'} = ($self->{'created'} =~ /(\d\d\d\d)/) ? $1 : '';
+			print STDERR "i:Found better title (".$self->{'title'}."), year (".$self->{'year'}.").\n"  if ($DEBUG);
+		}
+		$self->{'title'} = HTML::Entities::decode_entities($self->{'title'});
+		$self->{'title'} = uri_unescape($self->{'title'});
+		if ($html =~ m#\<h1[^\>]*\>([^\<]+)#s) {
+			$self->{'artist'} = $1;
+			$self->{'artist'} = HTML::Entities::decode_entities($self->{'artist'});
+			$self->{'artist'} = uri_unescape($self->{'artist'});
+			print STDERR "i:Found artist name (".$self->{'artist'}.").\n"  if ($DEBUG);
+		}
 		$self->{'imageurl'} = ($html =~ s#\"imageUrl\"\:\"([^\"]+)\"##s) ? $1 : '';
 		$self->{'iconurl'} = $self->{'imageurl'};
 		$self->{'total'} = $self->{'cnt'};
-		print STDERR "-SUCCESS2: --id=".$self->{'id'}."=\n--tit=".$self->{'title'}."=\n--icon=".$self->{'iconurl'}."=\n--streams=(".join('|',@{$self->{'streams'}}).")\n"  if ($DEBUG);
+		print STDERR "\n--SUCCESS2: ID=".$self->{'id'}."=\n--TITLE=".$self->{'title'}."\n--STREAMS=".join('|',@{$self->{'streams'}})."=\n"  if ($DEBUG);
 
 		bless $self, $class;   #BLESS IT!
 
@@ -443,6 +474,9 @@ sub new
 		$self->{'fccid'} = ($html =~ m#\"callLetters\"\s*\:\s*\"([^\"]+)\"#i) ? $1 : '';
 		$self->{'title'} = ($html =~ m#\"description\"\s*\:\s*\"([^\"]+)\"#) ? $1 : $url;
 		$self->{'title'} =~ s#http[s]?\:\/\/www\.iheart\.com\/live\/##;
+		$self->{'title'} = HTML::Entities::decode_entities($self->{'title'});
+		$self->{'title'} = uri_unescape($self->{'title'});
+		$self->{'description'} = $self->{'title'};
 		$self->{'imageurl'} = ($html =~ m#\"image_src\"\s+href=\"([^\"]+)\"#) ? $1 : '';
 #		$self->{'iconurl'} = $self->{'imageurl'} ? $self->{'imageurl'} . '?ops=fit(100%2C100)' : '';
 		$self->{'iconurl'} = ($html =~ m#\,\"logo\"\:\"([^\"]+)\"\,\"freq\"\:#) ? $1 : '';
@@ -522,7 +556,8 @@ sub getURL   #LIKE GET, BUT ONLY RETURN THE SINGLE ONE W/BEST BANDWIDTH AND RELI
 	my $self = shift;
 	my $arglist = (defined $_[0]) ? join('|',@_) : '';
 	my $idx = ($arglist =~ /\b\-?random\b/) ? int rand scalar @{$self->{'streams'}} : 0;
-	if ($arglist =~ /\b\-?noplaylists\b/ && ${$self->{'streams'}}[$idx] =~ /\.pls$/i) {
+	if ($arglist =~ /\b\-?noplaylists\b/ && ${$self->{'streams'}}[$idx] =~ /\.(pls|m3u8?)$/i) {
+		my $plType = $1;
 		my $firstStream = ${$self->{'streams'}}[$idx];
 		print STDERR "-getURL($idx): NOPLAYLISTS and (".${$self->{'streams'}}[$idx].")\n"  if ($DEBUG);
 		my $ua = LWP::UserAgent->new(@userAgentOps);		
@@ -543,16 +578,30 @@ sub getURL   #LIKE GET, BUT ONLY RETURN THE SINGLE ONE W/BEST BANDWIDTH AND RELI
 		}
 		my @lines = split(/\r?\n/, $html);
 		$firstStream = '';
-		my $firstTitle = '';
-		foreach my $line (@lines) {
-			if ($line =~ m#^\s*File\d+\=(.+)$#) {
-				$firstStream ||= $1;
-			} elsif ($line =~ m#^\s*Title\d+\=(.+)$#) {
-				$firstTitle ||= $1;
+		if ($plType =~ /pls/) {  #PLS:
+			my $firstTitle = '';
+			foreach my $line (@lines) {
+				if ($line =~ m#^\s*File\d+\=(.+)$#) {
+					$firstStream ||= $1;
+				} elsif ($line =~ m#^\s*Title\d+\=(.+)$#) {
+					$firstTitle ||= $1;
+				}
 			}
+			$self->{'title'} ||= $firstTitle;
+			print STDERR "-getURL(PLS): first=$firstStream= title=$firstTitle=\n"  if ($DEBUG);
+		} else {  #m3u8:
+			(my $urlpath = ${$self->{'streams'}}[$idx]) =~ s#[^\/]+$##;
+			foreach my $line (@lines) {
+				if ($line =~ m#^\s*([^\#].+)$#) {
+					my $urlpart = $1;
+					$urlpart =~ s#^\s+##;
+					$urlpart =~ s#^\/##;
+					$firstStream = ($urlpart =~ m#https?\:#) ? $urlpart : ($urlpath . '/' . $urlpart);
+					last;
+				}
+			}
+			print STDERR "-getURL(m3u?): first=$firstStream=\n"  if ($DEBUG);
 		}
-		$self->{'title'} ||= $firstTitle;
-		print STDERR "-getURL: first=$firstStream= title=$firstTitle=\n"  if ($DEBUG);
 		return $firstStream || ${$self->{'streams'}}[$idx];
 	}
 	return ${$self->{'streams'}}[$idx];
@@ -567,20 +616,21 @@ sub count
 sub getType
 {
 	my $self = shift;
-	return 'IHeartRadio';  #URL TO THE STATION'S THUMBNAIL ICON, IF ANY.
+	return 'IHeartRadio';  #STATION TYPE (FOR PARENT StreamFinder MODULE).
 }
 
 sub getID
 {
 	my $self = shift;
-	return $self->{'id'} || $self->{'fccid'}  if (defined($_[0]) && $_[0] !~ /fcc/i);
-	return $self->{'fccid'} || $self->{'id'};  #URL TO THE STATION'S CALL LETTERS OR IHEART-ID.
+	return $self->{'fccid'}  if (defined($_[0]) && $_[0] =~ /fcc/i);  #STATION'S CALL LETTERS OR IHEARTRADIO-ID.
+	return $self->{'id'};
 }
 
 sub getTitle
 {
 	my $self = shift;
-	return $self->{'title'};  #URL TO THE STATION'S TITLE(DESCRIPTION), IF ANY.
+	return $self->{'description'}  if (defined($_[0]) && $_[0] =~ /^\-?(?:long|desc)/i);
+	return $self->{'title'};  #STATION'S TITLE(DESCRIPTION), IF ANY.
 }
 
 sub getIconURL
@@ -594,7 +644,6 @@ sub getIconData
 	my $self = shift;
 	return ()  unless ($self->{'iconurl'});
 
-print STDERR "--getIconData: iconurl=".$self->{'iconurl'}."=\n";
 	my $ua = LWP::UserAgent->new(@userAgentOps);		
 	$ua->timeout($uops{'timeout'});
 	$ua->cookie_jar({});
@@ -609,9 +658,7 @@ print STDERR "--getIconData: iconurl=".$self->{'iconurl'}."=\n";
 	return ()  unless ($art_image);
 
 	(my $image_ext = $self->{'iconurl'}) =~ s/^.+\.//;
-print STDERR "--getIconData: ext0=$image_ext=\n";
 	$image_ext =~ s/[^A-Za-z].*$//;
-print STDERR "--getIconData: ext final=$image_ext=\n";
 
 	return ($image_ext, $art_image);
 }
