@@ -22,33 +22,33 @@ file.
 
 	use StreamFinder::Youtube;
 
-	my $station = new StreamFinder::Youtube(<url>);
+	my $video = new StreamFinder::Youtube(<url>);
 
-	die "Invalid URL or no streams found!\n"  unless ($station);
+	die "Invalid URL or no streams found!\n"  unless ($video);
 
-	my $firstStream = $station->get();
+	my $firstStream = $video->get();
 
 	print "First Stream URL=$firstStream\n";
 
-	my $url = $station->getURL();
+	my $url = $video->getURL();
 
 	print "Stream URL=$url\n";
 
-	my $stationTitle = $station->getTitle();
+	my $videoTitle = $video->getTitle();
 	
-	print "Title=$stationTitle\n";
+	print "Title=$videoTitle\n";
 	
-	my $stationID = $station->getID();
+	my $videoID = $video->getID();
 
-	print "Station ID=$stationID\n";
+	print "Video ID=$videoID\n";
 	
-	my $icon_url = $station->getIconURL();
+	my $icon_url = $video->getIconURL();
 
 	if ($icon_url) {   #SAVE THE ICON TO A TEMP. FILE:
 
-		my ($image_ext, $icon_image) = $station->getIconData();
+		my ($image_ext, $icon_image) = $video->getIconData();
 
-		if ($icon_image && open IMGOUT, ">/tmp/${stationID}.$image_ext") {
+		if ($icon_image && open IMGOUT, ">/tmp/${videoID}.$image_ext") {
 
 			binmode IMGOUT;
 
@@ -60,11 +60,11 @@ file.
 
 	}
 
-	my $stream_count = $station->count();
+	my $stream_count = $video->count();
 
 	print "--Stream count=$stream_count=\n";
 
-	my @streams = $station->get();
+	my @streams = $video->get();
 
 	foreach my $s (@streams) {
 
@@ -74,8 +74,8 @@ file.
 
 =head1 DESCRIPTION
 
-StreamFinder::Youtube accepts a valid Youtube video URL on youtube, 
-brighteon, vimeo, et. al. that the "youtube-dl" program can handle, 
+StreamFinder::Youtube accepts a valid full Youtube video ID or URL on 
+youtube, brighteon, vimeo, et. al. that the "youtube-dl" program can handle, 
 and returns the actual stream URL, title and cover art icon for that video.  
 The purpose is that one needs this URL in order to have the option to 
 stream the video in one's own choice of media player software rather 
@@ -87,8 +87,10 @@ open-source "audacious" audio player).  "fauxdacious" incorporates this
 module to decode and play youtube.com videos.  This is a submodule of the 
 general StreamFinder module.
 
-Depends:  WWW::YouTube::Download, LWP::UserAgent, URI::Escape, 
-and the separate program:  youtube-dl.
+Depends:  
+
+L<WWW::YouTube::Download>, L<I::Escape>, L<HTML::Entities>, L<LWP::UserAgent>, 
+and the separate application program:  youtube-dl.
 
 =head1 SUBROUTINES/METHODS
 
@@ -96,7 +98,7 @@ and the separate program:  youtube-dl.
 
 =item B<new>(I<url> [, "debug" [ => 0|(1)|2 ]] [, "notitle" [ => 0|(1) ]])
 
-Accepts a youtube.com URL and creates and returns a new station object, or 
+Accepts a youtube.com URL and creates and returns a new video object, or 
 I<undef> if the URL is not a valid youtube video or no streams are found.
 
 If "notitle" or "-notitle" is specified (or set to 1), a second call to 
@@ -104,11 +106,11 @@ youtube-dl to fetch the video's title is skipped, useful when called by
 StreamFinder::Tunein, which already has the title and youtube-dl will not 
 fetch it.
 
-=item $station->B<get>()
+=item $video->B<get>()
 
 Returns an array of strings representing all stream urls found.
 
-=item $station->B<getURL>([I<options>])
+=item $video->B<getURL>([I<options>])
 
 Similar to B<get>() except it only returns a single stream representing 
 the first valid stream found.  
@@ -117,40 +119,40 @@ Current options are:  I<-random> and I<-noplaylists>.  By default, the
 first ("best"?) stream is returned.  If I<-random> is specified, then 
 a random one is selected from the list of streams found.  
 If I<-noplaylists> is specified, and the stream to be returned is a 
-"playlist" (.pls or .m3u8 extension), it is first fetched and the first entry 
+"playlist" (.pls or .m3u? extension), it is first fetched and the first entry 
 in the playlist is returned.  This is needed by Fauxdacious Mediaplayer.
 
-=item $station->B<count>()
+=item $video->B<count>()
 
 Returns the number of streams found for the video.
 
-=item $station->B<getID>()
+=item $video->B<getID>()
 
 Returns the video's Youtube ID (numeric).
 
-=item $station->B<getTitle>()
+=item $video->B<getTitle>()
 
 Returns the video's title (description).  
 
-=item $station->B<getIconURL>()
+=item $video->B<getIconURL>()
 
 Returns the url for the video's "cover art" icon image, if any.
 
-=item $station->B<getIconData>()
+=item $video->B<getIconData>()
 
 Returns a two-element array consisting of the extension (ie. "png", 
 "gif", "jpeg", etc. and the actual icon image (binary data), if any.
 
-=item $station->B<getImageURL>()
+=item $video->B<getImageURL>()
 
 Returns the url for the video's "cover art" banner image.
 
-=item $station->B<getImageData>()
+=item $video->B<getImageData>()
 
 Returns a two-element array consisting of the extension (ie. "png", 
 "gif", "jpeg", etc. and the actual video's banner image (binary data).
 
-=item $station->B<getType>()
+=item $video->B<getType>()
 
 Returns the stream's type ("Youtube").
 
@@ -199,11 +201,11 @@ youtube
 
 youtube-dl
 
-LWP::UserAgent
+L<URI::Escape>, L<HTML::Entities>, L<LWP::UserAgent>, L<WWW::YouTube::Download>, youtube-dl
 
-WWW::YouTube::Download
+=head1 RECCOMENDS
 
-URI::Escape
+wget
 
 =head1 BUGS
 
@@ -286,6 +288,7 @@ package StreamFinder::Youtube;
 use strict;
 use warnings;
 use URI::Escape;
+use HTML::Entities ();
 use LWP::UserAgent ();
 use WWW::YouTube::Download;
 use vars qw(@ISA @EXPORT);
@@ -410,6 +413,8 @@ sub new
 		$self->{'title'} = $self->{'Url'} || $url  unless ($self->{'title'} =~ /\w/);  #STILL NO TITLE, USE URL.
 		print STDERR "i:Title not in metadata, set to (".$self->{'title'}.").\n"  if ($DEBUG);
 	}
+	$self->{'title'} = HTML::Entities::decode_entities($self->{'title'});
+	$self->{'title'} = uri_unescape($self->{'title'});
 	print STDERR "-count=".$self->{'cnt'}."= iconurl=".$self->{'iconurl'}."=\n"  if ($DEBUG);
 	print STDERR "--SUCCESS: stream url=".$self->{'Url'}."=\n"  if ($DEBUG);
 
@@ -431,7 +436,7 @@ sub getURL   #LIKE GET, BUT ONLY RETURN THE SINGLE ONE W/BEST BANDWIDTH AND RELI
 #	return $self->{'Url'};
 	my $arglist = (defined $_[0]) ? join('|',@_) : '';
 	my $idx = ($arglist =~ /\b\-?random\b/) ? int rand scalar @{$self->{'streams'}} : 0;
-	if ($arglist =~ /\b\-?noplaylists\b/ && ${$self->{'streams'}}[$idx] =~ /\.(pls|m3u8)$/i) {
+	if ($arglist =~ /\b\-?noplaylists\b/ && ${$self->{'streams'}}[$idx] =~ /\.(pls|m3u8?)$/i) {
 		my $plType = $1;
 		my $firstStream = ${$self->{'streams'}}[$idx];
 		print STDERR "-YT:getURL($idx): NOPLAYLISTS and (".${$self->{'streams'}}[$idx].")\n"  if ($DEBUG);
@@ -463,6 +468,8 @@ sub getURL   #LIKE GET, BUT ONLY RETURN THE SINGLE ONE W/BEST BANDWIDTH AND RELI
 				}
 			}
 			$self->{'title'} ||= $firstTitle;
+			$self->{'title'} = HTML::Entities::decode_entities($self->{'title'});
+			$self->{'title'} = uri_unescape($self->{'title'});
 			print STDERR "-YT:getURL(PLS): first=$firstStream= title=$firstTitle=\n"  if ($DEBUG);
 		} else {  #m3u8:
 			(my $urlpath = ${$self->{'streams'}}[$idx]) =~ s#[^\/]+$##;
@@ -475,7 +482,7 @@ sub getURL   #LIKE GET, BUT ONLY RETURN THE SINGLE ONE W/BEST BANDWIDTH AND RELI
 					last;
 				}
 			}
-			print STDERR "-YT:getURL(m3u8): first=$firstStream=\n"  if ($DEBUG);
+			print STDERR "-YT:getURL(m3u?): first=$firstStream=\n"  if ($DEBUG);
 		}
 		return $firstStream || ${$self->{'streams'}}[$idx];
 	}
@@ -491,25 +498,25 @@ sub count
 sub getType
 {
 	my $self = shift;
-	return 'Youtube';  #URL TO THE STATION'S THUMBNAIL ICON, IF ANY.
+	return 'Youtube';  #STATION TYPE (FOR PARENT StreamFinder MODULE).
 }
 
 sub getID
 {
 	my $self = shift;
-	return $self->{'id'};  #URL TO THE STATION'S THUMBNAIL ICON, IF ANY.
+	return $self->{'id'};  #VIDEO'S YOUTUBE-ID.
 }
 
 sub getTitle
 {
 	my $self = shift;
-	return $self->{'title'};  #URL TO THE STATION'S TITLE(DESCRIPTION), IF ANY.
+	return $self->{'title'};  #VIDEO'S TITLE(DESCRIPTION), IF ANY.
 }
 
 sub getIconURL
 {
 	my $self = shift;
-	return $self->{'iconurl'};  #URL TO THE STATION'S THUMBNAIL ICON, IF ANY.
+	return $self->{'iconurl'};  #URL TO THE VIDEO'S THUMBNAIL ICON, IF ANY.
 }
 
 sub getIconData
@@ -542,7 +549,7 @@ sub getIconData
 sub getImageURL
 {
 	my $self = shift;
-	return $self->{'imageurl'};  #URL TO THE STATION'S BANNER IMAGE, IF ANY.
+	return $self->{'imageurl'};  #URL TO THE VIDEO'S BANNER IMAGE, IF ANY.
 }
 
 sub getImageData
